SliceOp

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2022 License: MIT Imports: 0 Imported by: 0

README

sliceOP

This repository hold the slice operation package

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AppendVector

func AppendVector[T any](s []T, b []T) []T

AppendVector takes any kind of slice , combine them with first slice given and return the new slice,

func Cut

func Cut[T any](s []T, i int, j int) []T

func DeleteOrder

func DeleteOrder[T any](s []T, i int) []T

DeleteOrder takes slice of any kind ,a i index and delete the index element and returns the slice with the same order

func DeleteOrderless

func DeleteOrderless[T any](s []T, i int) []T

DeleteOrderless takes slice of any kind ,a i index and delete the index element and returns the slice without order

func Extend

func Extend[T any](s []T, j int) []T

func Insert

func Insert[T any](s []T, x T, i int) []T

func InsertVector

func InsertVector[T any](s []T, x []T, i int) []T

func Push

func Push[T any](s []T, x T) []T

func PushFront

func PushFront[T any](s []T, x T) []T

Types

This section is empty.

Jump to