Documentation
¶
Index ¶
- func AppendVector[T any](s []T, b []T) []T
- func Cut[T any](s []T, i int, j int) []T
- func DeleteOrder[T any](s []T, i int) []T
- func DeleteOrderless[T any](s []T, i int) []T
- func Extend[T any](s []T, j int) []T
- func Insert[T any](s []T, x T, i int) []T
- func InsertVector[T any](s []T, x []T, i int) []T
- func Push[T any](s []T, x T) []T
- func PushFront[T any](s []T, x T) []T
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppendVector ¶
func AppendVector[T any](s []T, b []T) []T
AppendVector takes any kind of slice , combine them with first slice given and return the new slice,
func DeleteOrder ¶
DeleteOrder takes slice of any kind ,a i index and delete the index element and returns the slice with the same order
func DeleteOrderless ¶
DeleteOrderless takes slice of any kind ,a i index and delete the index element and returns the slice without order
func InsertVector ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.